#!/usr/bin/env python
#coding=utf-8

import onelab, sys

OL = onelab.client(__file__)

# Display the geometry /mesh  in the GUI
#--------------------------------------
OL.openProject(OL.checkPath('aorta.geo'))
if OL.action == 'check' :
    OL.run('mesher', 'gmsh - ' + OL.checkPath('aorta.geo'),'')
 
# Define additional Onelab parameters
#--------------------------------------

VELPROFILE = OL.defineNumber('Parameters/1VELPROFILE', value=1, label = 'Flow profile', labels={1:'Flat', 2:'Parabolic'})
VMEAN = OL.defineNumber('Parameters/2VMEAN', value=0.1, label='Mean velocity (m/s)')
MU = OL.defineNumber('Parameters/3MU', value=0.004, label='Viscosity (Pa.s)')
RHO = OL.defineNumber('Parameters/4RHO', value=1000.0, label='Density (kg/m^3)')

RIN = OL.defineNumber('Parameters/5RIN',
             value=0.02, readOnly=1,
             label='Inlet radius (m)',
             attributes={'Highlight':'AliceBlue'})

rad = OL.getNumber('Parameters/5RIN')
reynolds  = OL.getNumber('Parameters/4RHO')*OL.getNumber('Parameters/2VMEAN')*2.*rad/OL.getNumber('Parameters/3MU')
flowrate  = OL.getNumber('Parameters/2VMEAN')*3.14*rad*rad
tauw = (4.*OL.getNumber('Parameters/3MU')/rad)*OL.getNumber('Parameters/2VMEAN')
gamma = tauw/OL.getNumber('Parameters/3MU')

OL.setNumber('Parameters/6REYNOLDS',
                value=reynolds, readOnly=1, 
                attributes={'Highlight':'AliceBlue'},
                label='Reynolds number')
OL.setNumber('Parameters/7FLOWRATE',
                value=flowrate, readOnly=1, 
                attributes={'Highlight':'AliceBlue'},
                label='Flow rate (m^3/s)')

#prepro
#--------
OL.preProcess('elmer', OL.checkPath('aorta.sif.ol'))
OL.preProcess('postpro', OL.checkPath('script.opt.ol'))
    
# Start solvers
#----------------
if OL.action == 'check' :
    exit(1)
    
OL.run('mesher', 'gmsh - ' +  OL.checkPath('aorta.geo'),'-3 -o "aorta.msh"')
OL.mergeFile(OL.checkPath('aorta.msh'))

OL.call('grid','ElmerGrid 14 2 aorta.msh -out mesh', rundir=OL.wdir)
if OL.isChanged('elmer'):
    OL.call('elmer','ElmerSolver aorta.sif', rundir=OL.wdir)

#postpro
#--------
OL.mergeFile(OL.checkPath('solution.pos'))
OL.call('postpro','gmsh solution.pos script.opt -', rundir=OL.wdir)
OL.mergeFile(OL.checkPath('cutpres.pos'))
OL.mergeFile(OL.checkPath('cutvel.pos'))
OL.mergeFile(OL.checkPath('wss.pos'))
OL.mergeFile(OL.checkPath('skinpres.pos'))
OL.mergeFile(OL.checkPath('skinvel.pos'))
OL.mergeFile(OL.checkPath('stream.pos'))

